# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcsb.endpoint import endpoint_data

class FindBrokerSLOHisListRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'CSB', '2017-11-18', 'FindBrokerSLOHisList')
		self.set_method('GET')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_CsbId(self):
		return self.get_query_params().get('CsbId')

	def set_CsbId(self,CsbId):
		self.add_query_param('CsbId',CsbId)

	def get_BeginDdHHmm(self):
		return self.get_query_params().get('BeginDdHHmm')

	def set_BeginDdHHmm(self,BeginDdHHmm):
		self.add_query_param('BeginDdHHmm',BeginDdHHmm)

	def get_EndDdHHmm(self):
		return self.get_query_params().get('EndDdHHmm')

	def set_EndDdHHmm(self,EndDdHHmm):
		self.add_query_param('EndDdHHmm',EndDdHHmm)